/*
 * Copyright 2011 BitMeister Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.bitmeister.asn1.codec.ber;

import java.io.IOException;
import java.io.OutputStream;

/**
 * Represents primitive BER octets.
 * 
 * <p>
 * This class represents a BER encoded octets that has only one contents octets.
 * </p>
 * 
 * @author WATANABE, Jun. <jwat at bitmeister.jp>
 */
class PrimitiveOctets extends BerOctets {

	private byte[] contents;

	/**
	 * Instantiates a {@code PrimitiveOctets}.
	 * 
	 * @param contents
	 */
	PrimitiveOctets(byte... contents) {
		this.contents = contents;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see jp.bitmeister.asn1.codec.ber.BerOctets#isConstructed()
	 */
	@Override
	boolean isConstructed() {
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see jp.bitmeister.asn1.codec.ber.BerOctets#octetsLength()
	 */
	@Override
	int octetsLength() {
		return this.contents.length;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * jp.bitmeister.asn1.codec.ber.BerOctets#writeContents(java.io.OutputStream
	 * )
	 */
	@Override
	void writeContents(OutputStream out) throws IOException {
		out.write(this.contents);
	}

}
