package jp.bitmeister.asn1.sample;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;

import jp.bitmeister.asn1.codec.ber.BerDecoder;
import jp.bitmeister.asn1.codec.ber.DerEncoder;
import jp.bitmeister.asn1.exception.ASN1DecodingException;
import jp.bitmeister.asn1.exception.ASN1EncodingException;
import jp.bitmeister.asn1.sample.FrightStatusTypes.Airport;
import jp.bitmeister.asn1.sample.FrightStatusTypes.FrightNumber;
import jp.bitmeister.asn1.sample.FrightStatusTypes.Information;
import jp.bitmeister.asn1.sample.FrightStatusTypes.Status;
import jp.bitmeister.asn1.type.ASN1TagClass;
import jp.bitmeister.asn1.type.builtin.INTEGER;
import jp.bitmeister.asn1.type.useful.UTCTime;

public class FrightStatusMain {

	public static void main(String[] args) {
				
		FrightStatus status = new FrightStatus(
				new FrightNumber("JP041"),
				new Information(
						new Airport(Airport.tokyo),
						new UTCTime("110627073000"),
						new UTCTime("110627073500")
						),
				new Information(
						new Airport(Airport.fukuoka),
						new UTCTime("110627090000"),
						null
						),
				new Status(
						ASN1TagClass.CONTEXT_SPECIFIC, 1, new INTEGER(5))
				);
		
		ByteArrayOutputStream bo = new ByteArrayOutputStream();
		DerEncoder enc = new DerEncoder(bo);
		try {
			enc.encode(status);
		}
		catch (ASN1EncodingException e) {
			e.printStackTrace();
		}
		
		ByteArrayInputStream bi = new ByteArrayInputStream(bo.toByteArray());
		BerDecoder dec = new BerDecoder(bi);
		try {
			FrightStatus result = dec.decode(FrightStatus.class);
			System.out.println(result);
		}
		catch (ASN1DecodingException e) {
			e.printStackTrace();
		}
	}

}
